@@ -90,5 +90,14 @@ LearnerRegrRpart = R6Class("LearnerRegrRpart", inherit = LearnerRegr,
   )
 )
 
+#' @export
+default_values.LearnerRegrRpart = function(x, search_space, task, ...) { # nolint
+  special_defaults = list(
+    minbucket = round(20 / 3)
+  )
+  defaults = insert_named(default_values(x$param_set), special_defaults)
+  defaults[search_space$ids()]
+}
+
 #' @include mlr_learners.R
 mlr_learners$add("regr.rpart", function() LearnerRegrRpart$new())
