@@ -22,6 +22,7 @@
 #' @template param_predict_sets
 #' @template param_task_properties
 #' @template param_packages
+#' @template param_label
 #' @template param_man
 #'
 #' @template seealso_measure
@@ -31,10 +32,10 @@ MeasureRegr = R6Class("MeasureRegr", inherit = Measure, cloneable = FALSE,
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function(id, param_set = ps(), range, minimize = NA, average = "macro", aggregator = NULL, properties = character(), predict_type = "response",
-      predict_sets = "test", task_properties = character(), packages = character(), man = NA_character_) {
+      predict_sets = "test", task_properties = character(), packages = character(), label = NA_character_, man = NA_character_) {
       super$initialize(id, task_type = "regr", param_set = param_set, range = range, minimize = minimize, average = average, aggregator = aggregator,
         properties = properties, predict_type = predict_type, predict_sets = predict_sets,
-        task_properties = task_properties, packages = packages, man = man)
+        task_properties = task_properties, packages = packages, label = label, man = man)
     }
   )
 )
